addpath(fullfile(getenv('JCMROOT'), 'ThirdPartySupport', 'Matlab'));

% Definition of the search domain
domain = {}; 
domain(1).name = 'height';
domain(1).domain = [50,200];
domain(2).name = 'width_bottom';
domain(2).domain = [60,200];
domain(3).name = 'width_top';
domain(3).domain = [60,200];
domain(4).name = 'periodicity';
domain(4).domain = [150,400];

% Definition of constraints
constraints = {};
constraints(1).name = 'max_width_bottom';
constraints(1).constraint = 'width_bottom - periodicity + 10';
constraints(2).name = 'max_width_top';
constraints(2).constraint = 'width_top - periodicity + 10';

% Creation of the study object with study_id 'Optimization of anti-reflection grating'
study = jcmwave_optimizer_create_study('domain', domain, 'constraints',constraints, ...
                    'name','Optimization of anti-reflection grating');
study.set_parameters('max_iter', 20, 'num_parallel', 2);


% Startup deamon
jcmwave_daemon_startup();
jcmwave_daemon_add_workstation('Hostname', 'localhost', ...
			       'Multiplicity', 2, ...
			       'NThreads', 1);

% The reflectivity is averaged over the wavelengths 600nm 700nm 800nm
lambdas = [600 700 800];
permittivities = [15.590 + 0.21635j 14.317 + 0.092101j 13.646 + 0.048345j];

% Run the minimization 
while(not(study.is_done))
    suggestion = study.get_suggestion();
    job_ids = start_jobs(suggestion.sample, lambdas, permittivities);
    study.open_jobs(job_ids, suggestion);
    if(study.num_open_suggestions == study.num_parallel)        
        % wait and gather results until an observation can be added
        [sug_results, sug_id] = study.gather_results();
        obs = reflectivity(sug_results, lambdas, permittivities, domain);                        
        study.add_observation(obs, sug_id);
    end
end



