%% shutdown a possibly running daemon
jcmwave_daemon_shutdown();

%% register a new computer resource
jcmwave_daemon_add_workstation('Hostname', 'localhost', ...
			       'Multiplicity', 2, ...
			       'NThreads', 1);


radii = [0.3 : 0.005 : 0.5];
job_ids = [];

%% loop over radius values
for radius = radii
  keys.radius = radius;

  %% jcmwave_solve immediately returns  a job identifier
  job_ids(end+1) = jcmwave_solve('mie2D.jcmp', keys, 'temporary', 'yes');
end

%% here we wait until all jobs are finished
[results, logs] = jcmwave_daemon_wait(job_ids);

%% now we collect the computed scattering cross section 
%% as in the the sequential example 
scattering_cross_section_scan = [];
for iR = 1 : length(radii)
  scs = real(results{iR}{2}.ElectromagneticFieldEnergyFlux{1});
  scattering_cross_section_scan(end+1, 1 : 2) = [radii(iR), scs];
end

%% plot scattering cross section against rod radius
radii = scattering_cross_section_scan(:, 1);
scs = scattering_cross_section_scan(:, 2);
plot(radii, scs, '-+', 'LineWidth', 2);
xlabel('radius [\mu m]', 'FontSize', 14);
ylabel('integral scattering cross section', 'FontSize', 14);
set(gca, 'FontSize', 14);

jcmwave_daemon_shutdown();



