%% holds computed scattering cross sections
scattering_cross_section_scan = [];

%% loop over radius values
for radius = [0.3 : 0.005 : 0.5]  
  fprintf('\nSolving for radius %5.2e', radius);

  % set current parameter and solve the project
  keys.radius = radius;
  results = jcmwave_solve('mie2D.jcmp', keys, 'logfile', 'null');

  scs = real(results{2}.ElectromagneticFieldEnergyFlux{1});

  % gather results
  scattering_cross_section_scan(end+1, 1 : 2) = [radius, scs];
end

%% plot scattering cross section against rod radius
radii = scattering_cross_section_scan(:, 1);
scs = scattering_cross_section_scan(:, 2);
plot(radii, scs, '-+', 'LineWidth', 2);
xlabel('radius [\mu m]', 'FontSize', 14);
ylabel('integral scattering cross section', 'FontSize', 14);
set(gca, 'FontSize', 14);




