%% shutdown a possibly running daemon
jcmwave_daemon_shutdown();

%% register a new computer resource
jcmwave_daemon_add_workstation('Hostname', 'localhost', ...
			       'Multiplicity', 2, ...
			       'NThreads', 1);

%% define default key values
default_keys.finite_element_degree = 3;
default_keys.maximum_sidelength = 0.1;
default_keys.radius = 0.3;

%% create resultbag. Results will be stored in file ./resultbag.mat
resultbag = jcmwave_resultbag('resultbag.mat');

%% define set of keys for a multi-dimensional parameter scan
sidelengths = 0.5 : -0.1 : 0.1;
radii = 0.3 : 0.02 : 0.5;
[scan1,scan2] = ndgrid(sidelengths, radii);
keyset = repmat(default_keys,size(scan1)); %fill keyset with default keys
for ii = 1 : numel(keyset)
    keyset(ii).maximum_sidelength = scan1(ii);
    keyset(ii).radius = scan2(ii);
end

%% run the parameter scan
job_ids = [];
for ii = 1 : numel(keyset)
   keys = keyset(ii);
   job_ids(end+1) = jcmwave_solve('mie2D.jcmp', keys, resultbag, 'temporary', 'yes');
end

% jcm_deamon_wait adds all results to the resultbag
jcmwave_daemon_wait(job_ids, resultbag);

%% collect the computed scattering cross section with the help of resultbag.get_result()
scattering_cross_section_scan = zeros(length(sidelengths),length(radii));
for ii = 1 : numel(keyset)
   keys = keyset(ii);
   result = resultbag.get_result(keys);
   scs = real(result{2}.ElectromagneticFieldEnergyFlux{1});
   scattering_cross_section_scan(ii) = scs;
end

%% plot scattering cross section against rod radius for different maximum sidelengths
plot(radii, scattering_cross_section_scan, '-+', 'LineWidth', 2);
xlabel('radius [\mu m]', 'FontSize', 14);
ylabel('integral scattering cross section', 'FontSize', 14);
legend(num2str(sidelengths','side length %.1f'));
set(gca, 'FontSize', 14);


jcmwave_daemon_shutdown();